@@ -1,7 +1,7 @@
 package POE::Component::IKC::Channel;
 
 ############################################################
-# $Id: Channel.pm 468 2009-05-01 17:01:00Z fil $
+# $Id: Channel.pm 472 2009-05-01 18:28:08Z fil $
 # Based on tests/refserver.perl
 # Contributed by Artur Bergman <artur@vogon-solutions.com>
 # Revised for 0.06 by Rocco Caputo <troc@netrus.net>
@@ -27,7 +27,7 @@ use Data::Dumper;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_channel);
-$VERSION = '0.2100';
+$VERSION = '0.2101';
 
 sub DEBUG { 0 }
 
@@ -532,7 +532,9 @@ sub _channel_unregister
 ------------------------------------------
 WARN
         # 2005/06 Tell IKC we closed the connection
-        $poe_kernel->call('IKC', 'unregister', $heap->{remote_ID});
+        unless( $heap->{shutdown} ) {
+            $poe_kernel->call('IKC', 'unregister', $heap->{remote_ID});
+        }
         delete $heap->{remote_ID};
     }
                                         # either way, shut down
@@ -607,6 +609,8 @@ sub channel_receive
 
     DEBUG && 
         warn "$$: Received data...\n";
+    return if $heap->{shutdown};
+
     # we won't trust the other end to set this properly
     $request->{errors_to}={ kernel=>$heap->{remote_ID},
                             session=>'IKC',
